**To delete a service**

The following ``delete-service`` example deletes a service. ::

    aws servicediscovery delete-service \
        --id srv-p5zdwlg5uvvzjita

This command produces no output.

For more information, see `Deleting services <https://docs.aws.amazon.com/cloud-map/latest/dg/deleting-services.html>`__ in the *AWS Cloud Map Developer Guide*.

